==> ansible-9.2.0.tar.gz: ansible-9.2.0/ansible_collections/cisco/iosxr/tests/unit/modules/network/iosxr/test_iosxr_lacp.py <==
# (c) 2021 Red Hat Inc.
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Ansible is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.

# Make coding more python3-ish

from __future__ import absolute_import, division, print_function


__metaclass__ = type

from ansible_collections.cisco.iosxr.plugins.modules import iosxr_lacp
from ansible_collections.cisco.iosxr.tests.unit.compat.mock import patch
from ansible_collections.cisco.iosxr.tests.unit.modules.utils import set_module_args

from .iosxr_module import TestIosxrModule, load_fixture


class TestIosxrLacpModule(TestIosxrModule):
    module = iosxr_lacp

    def setUp(self):
        super(TestIosxrLacpModule, self).setUp()

        self.mock_get_config = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
        )
        self.get_config = self.mock_get_config.start()

        self.mock_load_config = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
        )
        self.load_config = self.mock_load_config.start()

        self.mock_get_resource_connection_config = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base.get_resource_connection",
        )
        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()

        self.mock_get_resource_connection_facts = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts.get_resource_connection",
        )
        self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
        self.mock_execute_show_command = patch(
            "ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.facts.lacp.lacp.LacpFacts.get_config",
        )
        self.execute_show_command = self.mock_execute_show_command.start()

    def tearDown(self):
        super(TestIosxrLacpModule, self).tearDown()
        self.mock_get_resource_connection_config.stop()
        self.mock_get_resource_connection_facts.stop()
        self.mock_get_config.stop()
        self.mock_load_config.stop()
        self.mock_execute_show_command.stop()

    def _prepare(self):
        def load_from_file(*args, **kwargs):
            return load_fixture("iosxr_lacp_config.cfg")

        self.execute_show_command.side_effect = load_from_file

    def test_iosxr_lacp_merged(self):
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=12,
                        mac=dict(address="00c1.4c00.bd15"),
                    ),
                ),
                state="merged",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd15",
            "lacp system priority 12",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_merged_idempotent(self):
        self._prepare()
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=12,
                        mac=dict(address="00c1.4c00.bd15"),
                    ),
                ),
                state="merged",
            ),
        )
        self.execute_module(changed=False, commands=[])

    def test_iosxr_lacp_replaced(self):
        self._prepare()
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=11,
                        mac=dict(address="00c1.4c00.bd12"),
                    ),
                ),
                state="replaced",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd12",
            "lacp system priority 11",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_overridden(self):
        self._prepare()
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=11,
                        mac=dict(address="00c1.4c00.bd12"),
                    ),
                ),
                state="overridden",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd12",
            "lacp system priority 11",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_deleted(self):
        self._prepare()
        set_module_args(dict(state="deleted"))
        commands = [
            "no lacp system mac",
            "no lacp system priority",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_rendered(self):
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=11,
                        mac=dict(address="00c1.4c00.bd12"),
                    ),
                ),
                state="rendered",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd12",
            "lacp system priority 11",
        ]
        result = self.execute_module(changed=False)
        self.assertEqual(sorted(result["rendered"]), sorted(commands))

==> ansible-11.0.0a1.tar.gz: ansible-11.0.0a1/ansible_collections/cisco/iosxr/tests/unit/modules/network/iosxr/test_iosxr_lacp.py <==
# (c) 2021 Red Hat Inc.
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Ansible is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.

# Make coding more python3-ish

from __future__ import absolute_import, division, print_function


__metaclass__ = type

from unittest.mock import patch

from ansible_collections.cisco.iosxr.plugins.modules import iosxr_lacp
from ansible_collections.cisco.iosxr.tests.unit.modules.utils import set_module_args

from .iosxr_module import TestIosxrModule, load_fixture


class TestIosxrLacpModule(TestIosxrModule):
    module = iosxr_lacp

    def setUp(self):
        super(TestIosxrLacpModule, self).setUp()

        self.mock_get_config = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
        )
        self.get_config = self.mock_get_config.start()

        self.mock_load_config = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
        )
        self.load_config = self.mock_load_config.start()

        self.mock_get_resource_connection_config = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base.get_resource_connection",
        )
        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()

        self.mock_get_resource_connection_facts = patch(
            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts.get_resource_connection",
        )
        self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
        self.mock_execute_show_command = patch(
            "ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.facts.lacp.lacp.LacpFacts.get_config",
        )
        self.execute_show_command = self.mock_execute_show_command.start()

    def tearDown(self):
        super(TestIosxrLacpModule, self).tearDown()
        self.mock_get_resource_connection_config.stop()
        self.mock_get_resource_connection_facts.stop()
        self.mock_get_config.stop()
        self.mock_load_config.stop()
        self.mock_execute_show_command.stop()

    def _prepare(self):
        def load_from_file(*args, **kwargs):
            return load_fixture("iosxr_lacp_config.cfg")

        self.execute_show_command.side_effect = load_from_file

    def test_iosxr_lacp_merged(self):
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=12,
                        mac=dict(address="00c1.4c00.bd15"),
                    ),
                ),
                state="merged",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd15",
            "lacp system priority 12",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_merged_idempotent(self):
        self._prepare()
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=12,
                        mac=dict(address="00c1.4c00.bd15"),
                    ),
                ),
                state="merged",
            ),
        )
        self.execute_module(changed=False, commands=[])

    def test_iosxr_lacp_replaced(self):
        self._prepare()
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=11,
                        mac=dict(address="00c1.4c00.bd12"),
                    ),
                ),
                state="replaced",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd12",
            "lacp system priority 11",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_overridden(self):
        self._prepare()
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=11,
                        mac=dict(address="00c1.4c00.bd12"),
                    ),
                ),
                state="overridden",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd12",
            "lacp system priority 11",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_deleted(self):
        self._prepare()
        set_module_args(dict(state="deleted"))
        commands = [
            "no lacp system mac",
            "no lacp system priority",
        ]
        result = self.execute_module(changed=True)
        self.assertEqual(sorted(result["commands"]), sorted(commands))

    def test_iosxr_lacp_rendered(self):
        set_module_args(
            dict(
                config=dict(
                    system=dict(
                        priority=11,
                        mac=dict(address="00c1.4c00.bd12"),
                    ),
                ),
                state="rendered",
            ),
        )
        commands = [
            "lacp system mac 00c1.4c00.bd12",
            "lacp system priority 11",
        ]
        result = self.execute_module(changed=False)
        self.assertEqual(sorted(result["rendered"]), sorted(commands))
